powered by
retrieve words that are close to occurrences of pattern
concordance(freqs, titles.vec, texts.vec, starts, window, odir)
returns no value but has side effect of generating graphs
return value of frequency()
character vector containing the titles of the stories
character vector of entire text
integer vector of starting positions
integer number of lines to take before and after the pattern match
character string containing the full path name for the output directory
# \donttest{ con<-concordance(freqs,titles.vec[3],texts.vec,starts,window=2,odir=tempdir()) # }
Run the code above in your browser using DataLab