Learn R Programming

SherlockHolmes (version 1.0.2)

readTitles: readTitles

Description

read and edit titles to remove blank lines and white space

Usage

readTitles(titles)

Value

a character vector of titles

Arguments

titles

is a character string containing the full path name for a text file containing the titles of the stories in the same order that thney appear in the texts file

Examples

Run this code
titles<-system.file("extdata/contents3.txt",package="SherlockHolmes")
rt<-readTitles(titles)

Run the code above in your browser using DataLab