read and edit titles to remove blank lines and white space
Usage
readTitles(titles)
Value
a character vector of titles
Arguments
titles
is a character string containing the full path name for a text file containing the titles of the stories in the same order that thney appear in the texts file